Learn R Programming

pmxNODE (version 0.1.0)

derivative_calc_mlx: Internal: Calculate the derivatives from a NN in Monolix

Description

Calculate the derivatives from a NN for derivative versus state plots

Usage

derivative_calc_mlx(
  nn_name,
  parms,
  inputs,
  n_hidden = 5,
  time_nn = FALSE,
  act = "ReLU",
  beta = 20
)

Value

A vector of derivatives of the NN for the state values

Arguments

nn_name

(string) Name of the NN, e.g., “c” for NNc(...)

parms

(named vector) Named vector of estimated parameters from the NN; Namings are e.g. Wc_11 for the weight from input to the first hidden unit of NN called "c"

inputs

(vector) Vector cointain the state values for which the derivatives should be calculated

n_hidden

(numeric) Number of neurons in the hidden layer, default value is 5

time_nn

(boolean) Whether the NN is a time-dependent NN and negative weights should be applied from input to hidden layer. Default values is FALSE.

act

(string) Activation function used in the NN. Currently "ReLU" and "Softplus" available.

beta

(numeric) Beta value for the Softplus activation function, only applicable if act="Softplus"; Default to 20.

Author

Dominic Bräm