This functions allows to generate derivative versus state data for a neural network from a NODE in Monolix with individual parameters.
ind_der_vs_state_mlx(
nn_name,
min_state = NULL,
max_state = NULL,
inputs = NULL,
est_parms = NULL,
mlx_file = NULL,
time_nn = FALSE,
length_out = 100,
act = "ReLU",
beta = 20,
transform = NULL
)Dataframe with columns for the state and the corresponding individual derivatives
(string) Name of the NN, e.g., “c” for NNc(...)
(numeric) Value of minimal state for which the derivative should be calculated (optional if inputs is given, ignored if inputs is defined)
(numeric) Value of maximal state for which the derivative should be calculated (optional if inputs is given, ignored if inputs is defined)
(numeric vector) Vector of input values for which derivatives should be calculated (optional if min_state and max_state is given)
(named vector; semi-optional) A data frame with estimated individual parameters from the NN extracted through the indparm_extractor_mlx function. For optionality, see Details.
(string; semi-optional) (path)/name of the Monolix run. Must include ".mlxtran" and estimation bust have been run previously. For optionality, see Details.
(boolean) Whether the neural network to analyze is a time-dependent neural network or not. Default values is FALSE.
(numeric) Number of states between min_state and max_state for derivative calculations.
(string) Activation function used in the NN. Currently "ReLU" and "Softplus" available.
(numeric) Beta value for the Softplus activation function, only applicable if act="Softplus"; Default to 20.
(string) Mathematical exression as string to transform the NN output. Independent variable must be called NN, e.g., "1/(1+exp(-NN))" for sigmoidal transformation.
Dominic Bräm
Either est_parms or mlx_file must be given. If both arguments are given, est_parms is prioritized.