Learn R Programming

pmxNODE (version 0.1.0)

ind_der_vs_state_nm: Generate Derivative versus State with individual parameters (NONMEM)

Description

This functions allows to generate derivative versus state data for a neural network from a NODE in NONMEM with individual parameters.

Usage

ind_der_vs_state_nm(
  nn_name,
  min_state = NULL,
  max_state = NULL,
  inputs = NULL,
  est_parms = NULL,
  nm_res_file = NULL,
  nm_phi_file = NULL,
  length_out = 100,
  time_nn = FALSE,
  act = "ReLU",
  beta = 20,
  transform = NULL
)

Value

Dataframe with columns for the state and the corresponding individual derivatives

Arguments

nn_name

(string) Name of the NN, e.g., “c” for NNc(...)

min_state

(numeric) Value of minimal state for which the derivative should be calculated (optional if inputs is given, ignored if inputs is defined)

max_state

(numeric) Value of maximal state for which the derivative should be calculated (optional if inputs is given, ignored if inputs is defined)

inputs

(numeric vector) Vector of input values for which derivatives should be calculated (optional if min_state and max_state is given)

est_parms

(named vector; semi-optional) A data frame with estimated individual parameters from the NN extracted through the indparm_extractor_nm function. For optionality, see Details.

nm_res_file

(string; semi-optional) (path)/name of the results file of a NONMEM run, must include file extension, e.g., “.res”. For optionality, see Details.

nm_phi_file

(string; semi-optional) (path)/name of the phi file of a NONMEM run, must include file extension “.phi”. For optionality, see Details.

length_out

(numeric) Number of states between min_state and max_state for derivative calculations.

time_nn

(boolean) Whether the neural network to analyze is a time-dependent neural network or not. Default values is FALSE.

act

(string) Activation function used in the NN. Currently "ReLU" and "Softplus" available.

beta

(numeric) Beta value for the Softplus activation function, only applicable if act="Softplus"; Default to 20.

transform

(string) Mathematical exression as string to transform the NN output. Independent variable must be called NN, e.g., "1/(1+exp(-NN))" for sigmoidal transformation.

Author

Dominic Bräm

Details

Either est_parms or nm_res_file and nm_phi_file must be given. If both arguments are given, est_parms is prioritized.