Learn R Programming

pmxNODE (version 0.1.0)

indparm_extractor_nlmixr: nlmixr individual estimations extractor

Description

When the nlmixr model has been run, this function allows to extract the estimated individual parameters for NN parameters by combining fixed effects and random effects

Usage

indparm_extractor_nlmixr(fit_obj)

Value

Data frame with individual parameter estimates for NN parameters

Arguments

fit_obj

Nlmixr fit object with random effects on NN parameters

Author

Dominic Bräm

Examples

Run this code
if (FALSE) {
fit_ind <- nlmixr(model_with_iiv,data=data,est="saem")
est_parms <- indparm_extractor_nlmixr(fit_ind)
}

Run the code above in your browser using DataLab