Learn R Programming

pmxNODE (version 0.1.0)

nn_eta_initializer_nlmixr: Internal: Initialize random effects on NN parameters in nlmixr

Description

Define the standard deviation of random effects on NN parameters for the ini section of the nlmixr model

Usage

nn_eta_initializer_nlmixr(
  number,
  n_hidden = 5,
  eta_scale = 0.1,
  time_nn = FALSE
)

Value

Vector of initial random effects on NN parameters for one specific NN

Arguments

number

(string) Name of the NN, e.g., “1” for NN1(...)

n_hidden

(numeric) Number of neurons in the hidden layer, default value is 5

eta_scale

(numeric) Initial standard deviation of random effects on NN parameters

time_nn

(boolean) Definition whether NN is time-dependent (TRUE) or not (FALSE)

Author

Dominic Bräm