Get parameter names for one specific NN in the model, i.e., weight and bias names
nn_theta_def_mlx(number, n_hidden = 5, time_nn = FALSE)Vector with all NN parameter names
(string) Name of the NN, e.g., “1” for NN1(...)
(numeric) Number of neurons in the hidden layer, default value is 5
(boolean) Whether the neural network to analyze is a time-dependent neural network or not. Default values is FALSE.
Dominic Bräm