Learn R Programming

pmxNODE (version 0.1.0)

nn_theta_def_nm: Internal: Define NN THETAs in NONMEM

Description

Define NN THETAS used in the $PK section in NONMEM

Usage

nn_theta_def_nm(number, theta_start, n_hidden = 5, time_nn = FALSE)

Value

Vector with all NN parameter THETA definitions for a NN

Arguments

number

(string) Name of the NN, e.g., “1” for NN1(...)

theta_start

(numeric) Number with which to start the THETA count of NN parameters

n_hidden

(numeric) Number of neurons in the hidden layer, default value is 5

time_nn

(boolean) Whether the neural network to analyze is a time-dependent neural network or not. Default values is FALSE.

Author

Dominic Bräm

Details

Parameter definition in form of lW = THETA(X) with X the next number of THETA
e.g., if
lV = THETA(1)
lkel = THETA(2)
X is equal to 3