This functions allows to generate derivative versus state data for a neural network from a NODE in nlmixr2.
der_vs_state_nlmixr(
nn_name,
min_state = NULL,
max_state = NULL,
inputs = NULL,
est_parms = NULL,
fit_obj = NULL,
length_out = 100,
time_nn = FALSE,
act = "ReLU",
beta = 20
)Dataframe with columns for the state and the corresponding derivatives
(string) Name of the NN, e.g., “c” for NNc(...)
(numeric) Value of minimal state for which the derivative should be calculated (optional if inputs is given, ignored if inputs is defined)
(numeric) Value of maximal state for which the derivative should be calculated (optional if inputs is given, ignored if inputs is defined)
(numeric vector) Vector of input values for which derivatives should be calculated (optional if min_state and max_state is given)
(named vector; semi-optional) Named vector of estimated parameters form fit$fixef. For optionality, see Details.
(nlmixr fit object; semi-optional) The fit-object from nlmixr2(...). For optionality, see Details.
(numeric) Number of states between min_state and max_state for derivative calculations.
(boolean) Whether the neural network to analyze is a time-dependent neural network or not. Default values is FALSE.
(string) Activation function used in the NN. Currently "ReLU" and "Softplus" available.
(numeric) Beta value for the Softplus activation function, only applicable if act="Softplus"; Default to 20.
Dominic Bräm
Either est_parms or fit_obj must be given. If both arguments are given, est_parms is prioritized.