This functions allows to generate right-hand side data for multiple individuals with individual parameter sets, i.e., combined derivative data of multiple NNs and base-R operations.
ind_rhs_calc_nm(
rhs,
inputs,
group,
est_parms = NULL,
nm_res_file = NULL,
nm_phi_file = NULL,
time_nn = NULL,
act = NULL,
beta = 20
)Dataframe with columns for the inputs and the combined right-hand side data.
(string) String of right-hand side
(dataframe) Dataframe of inputs, with corresponding columns (including matching column names for each variable in rhs.
(string) Name of column in inputs dataframe defining groups/individuals.
(dataframe; semi-optional) A data frame with estimated individual parameters from the NN extracted through the indparm_extractor_nm function. For optionality, see Details.
(string; semi-optional) (path)/name of the results file of a NONMEM run, must include file extension, e.g., “.res”. For optionality, see Details.
(string; semi-optional) (path)/name of the phi file of a NONMEM run, must include file extension “.phi”. For optionality, see Details.
(boolean vector) Vector for each NN in rhs defining whether the neural network is a time-dependent neural network or not. Default value for all NN is FALSE.
(character vector) Vector for each NN in rhs defining the activation function used in the NN. Default value for all NN is "ReLU".
(numeric) Beta value for the Softplus activation function, only applicable if any act is softplus; Default to 20.
Dominic Bräm
Either est_parms or nm_res_file and nm_phi_file must be given. If both arguments are given, est_parms is prioritized.