When the nlmixr model has been run, this function allows to extract the
estimated individual parameters for NN parameters by combining fixed effects and random effects
Usage
indparm_extractor_nlmixr(fit_obj)
Value
Data frame with individual parameter estimates for NN parameters
Arguments
fit_obj
Nlmixr fit object with random effects on NN parameters