- mlx_path
(string) (Path/)Name of the unconverted Monolix model file
- pop_only
(boolean) If the generated Monolix .mlxtran file should be a fit without (TRUE) or with (FALSE)
inter-individual variability on NN parameters
- theta_scale
(numeric) Scale in which typical NN parameter values are initialized, default is 0.1, i.e., weights are
initialized between -0.3 and 0.3
- eta_scale
(numeric) Initial standard deviation of random effects on NN parameters, default is 0.1
- pre_fixef
(named vector) Specific initial values for typical parameters, can be optained with the
pre_fixef_extractor_mlx function from a previous Monolix run
- gen_mlx_file
(boolean) If a Monolix .mlxtran file with already initialized parameters and estimation
settigs should be generated
- mlx_name
(string) Optional, name of the generated Monolix file (mlx_name.mlxtran). If no name is given and
gen_mlx_file=TRUE, name of the Monolix file will be unconverted_model_name_mlx_file_pop/ind.mlxtran,
with pop or ind depending whether pop=TRUE or pop=FALSE,respectively.
- data_file
(string) Required if gen_mlx_file=TRUE, (Path/)Name of the data file to be used
- header_types
(vector) Required if gen_mlx_file=TRUE, Vector of strings describing column types of data. Possible header types:
ignore, id, time, observation, amount, contcov, catcov, occ, evid, mdv, obsid, cens, limit, regressor, nominaltime, admid, rate, tinf, ss, ii, addl, date
- obs_types
(list) List of types of observations, e.g., “continuous”; only required if non-continuous observations
- mapping
(list) List of mapping between model outputs and observation IDs
- seed
(numeric) Seed for random parameter initialization.