Define random effects of NN parameters as ETAs used in the $PK section in NONMEM
nn_eta_def_nm(number, eta_start, n_hidden = 5, time_nn = FALSE)Vector with all NN parameter ETA definitions for a NN
(string) Name of the NN, e.g., “1” for NN1(...)
(numeric) Number with which to start the ETA count of NN parameters
(numeric) Number of neurons in the hidden layer, default value is 5
(boolean) Whether the neural network to analyze is a time-dependent neural network or not. Default values is FALSE.
Dominic Bräm
Parameter definition in form of etaW = ETA(X) with X the next number of ETA
e.g., if
etaV = ETA(1)
etakel = ETA(2)
X is equal to 3