Define the standard deviation of random effects on NN parameters for the ini section of the nlmixr model
nn_eta_initializer_nlmixr(
number,
n_hidden = 5,
eta_scale = 0.1,
time_nn = FALSE
)Vector of initial random effects on NN parameters for one specific NN
(string) Name of the NN, e.g., “1” for NN1(...)
(numeric) Number of neurons in the hidden layer, default value is 5
(numeric) Initial standard deviation of random effects on NN parameters
(boolean) Definition whether NN is time-dependent (TRUE) or not (FALSE)
Dominic Bräm