Define NN parameters consisting of typical parameter and potentially random effects in the model section of a nlmixr model
nn_parm_setter_nlmixr(
number,
pop = FALSE,
n_hidden = 5,
eta_model = c("prop", "add"),
time_nn = FALSE
)List of parameter definition to be used in the model section of the nlmixr model
(string) Name of the NN, e.g., “1” for NN1(...)
(boolean) Whether population fit without inter-individual variability is performed (TRUE) or whether model is fitted with inter-individual variability (FALSE)
(numeric) Number of neurons in the hidden layer, default value is 5
(string)
“prop” is of form W = lW * EXP(etaW)
“add” is of form W = lW + etaW
Defaul value is “prop”
(boolean) Definition whether NN is time-dependent (TRUE) or not (FALSE)
Dominic Bräm
eta_model is currently set to proportional as previous investigations showed better stability of fit with this setting