Define NN THETAS used in the $PK section in NONMEM
nn_theta_def_nm(number, theta_start, n_hidden = 5, time_nn = FALSE)Vector with all NN parameter THETA definitions for a NN
(string) Name of the NN, e.g., “1” for NN1(...)
(numeric) Number with which to start the THETA count of NN parameters
(numeric) Number of neurons in the hidden layer, default value is 5
(boolean) Whether the neural network to analyze is a time-dependent neural network or not. Default values is FALSE.
Dominic Bräm
Parameter definition in form of lW = THETA(X) with X the next number of THETA
e.g., if
lV = THETA(1)
lkel = THETA(2)
X is equal to 3