This functions allows to generate right-hand side data, i.e., combined derivative data of multiple NNs and base-R operations.
rhs_calc_mlx(
rhs,
inputs,
est_parms = NULL,
mlx_file = NULL,
time_nn = NULL,
act = NULL,
beta = 20
)Dataframe with columns for the inputs and the combined right-hand side data.
(string) String of right-hand side, e.g., "NNc + WT * NNct"
(dataframe) Dataframe of inputs, with corresponding columns (including matching column names for each variable in rhs, e.g., NNc, WT, and NNct).
(named vector; semi-optional) Named vector of estimated parameters from the NN extracted through the pre_fixef_extractor_mlx function. For optionality, see Details.
(string; semi-optional) (path)/name of the Monolix run. Must include ".mlxtran" and estimation bust have been run previously. For optionality, see Details.
(boolean vector) Vector for each NN in rhs defining whether the neural network is a time-dependent neural network or not. Default value for all NN is FALSE.
(character vector) Vector for each NN in rhs defining the activation function used in the NN. Default value for all NN is "ReLU".
(numeric) Beta value for the Softplus activation function, only applicable if any act is softplus; Default to 20.
Dominic Bräm
Either est_parms or mlx_file must be given. If both arguments are given, est_parms is prioritized.